@@ -1,8 +1,9 @@
 def print_lol(the_entry, level = 0):
   if not isinstance(the_entry,list) :
+    print(level)
     for tab_stop in range(level):
       print("\t", end='')
-    print(the_entry) 
+    print(the_entry, sep="") 
   else:
     for e in the_entry:
       print_lol(e, level + 1)
